=== modified file 'lib/lp/answers/browser/question.py'
--- lib/lp/answers/browser/question.py	2009-11-01 05:02:04 +0000
+++ lib/lp/answers/browser/question.py	2009-11-11 22:17:17 +0000
@@ -89,24 +89,19 @@
             icon = 'mail'
         return Link('+subscribe', text, icon=icon)
 
-
-class QuestionEditMenu(NavigationMenu, QuestionLinksMixin):
-    """A menu for different aspects of editing a object."""
-
-    usedfor = IQuestion
-    facet = 'answers'
-    title = 'Edit question'
-    links = ['edit', 'changestatus', 'reject', 'subscription']
-
     def edit(self):
         """Return a Link to the edit view."""
         text = 'Edit question'
         return Link('+edit', text, icon='edit')
 
-    @enabled_with_permission('launchpad.Admin')
-    def changestatus(self):
-        """Return a Link to the change status view."""
-        return Link('+change-status', _('Change status'), icon='edit')
+
+class QuestionEditMenu(NavigationMenu, QuestionLinksMixin):
+    """A menu for different aspects of editing a object."""
+
+    usedfor = IQuestion
+    facet = 'answers'
+    title = 'Edit question'
+    links = ['edit', 'reject', 'subscription']
 
     def reject(self):
         """Return a Link to the reject view."""
@@ -119,13 +114,19 @@
     """Context menu of actions that can be performed upon a Question."""
     usedfor = IQuestion
     facet = 'answers'
-    links = ['history', 'linkbug', 'unlinkbug', 'makebug', 'linkfaq',
-        'createfaq']
+    links = [
+        'history', 'linkbug', 'unlinkbug', 'makebug', 'linkfaq',
+        'createfaq', 'edit', 'changestatus']
 
     def initialize(self):
         """Initialize the menu from the Question's state."""
         self.has_bugs = bool(self.context.bugs)
 
+    @enabled_with_permission('launchpad.Admin')
+    def changestatus(self):
+        """Return a Link to the change status view."""
+        return Link('+change-status', _('Change status'), icon='edit')
+
     def history(self):
         """Return a Link to the history view."""
         text = 'History'
@@ -153,7 +154,11 @@
         """Link for linking to a FAQ."""
         text = 'Link to a FAQ'
         summary = 'Link this question to a FAQ.'
-        return Link('+linkfaq', text, summary, icon='add')
+        if self.context.faq is None:
+            icon = 'add'
+        else:
+            icon = 'edit'
+        return Link('+linkfaq', text, summary, icon=icon)
 
     def createfaq(self):
         """LInk for creating a FAQ."""

=== added file 'lib/lp/answers/browser/tests/test_menus.py'
--- lib/lp/answers/browser/tests/test_menus.py	1970-01-01 00:00:00 +0000
+++ lib/lp/answers/browser/tests/test_menus.py	2009-11-11 22:17:17 +0000
@@ -0,0 +1,58 @@
+# Copyright 2009 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+__metaclass__ = type
+
+import unittest
+
+from zope.component import getUtility
+
+from canonical.testing.layers import DatabaseFunctionalLayer
+
+from lp.answers.browser.question import QuestionEditMenu, QuestionExtrasMenu
+from lp.services.worlddata.interfaces.language import ILanguageSet
+from lp.testing import login_person, TestCaseWithFactory
+from lp.testing.menu import check_menu_links
+
+
+class TestQuestionMenus(TestCaseWithFactory):
+    """Test specification menus links."""
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        TestCaseWithFactory.setUp(self)
+        self.person = self.factory.makePerson()
+        login_person(self.person)
+        self.question = self.factory.makeQuestion()
+
+    def test_QuestionEditMenu(self):
+        menu = QuestionEditMenu(self.question)
+        self.assertTrue(check_menu_links(menu))
+
+    def test_QuestionExtrasMenu(self):
+        menu = QuestionExtrasMenu(self.question)
+        self.assertTrue(check_menu_links(menu))
+
+    def test_link_linkfaq(self):
+        # A question without a linked FAQ has an 'add' icon.
+        menu = QuestionExtrasMenu(self.question)
+        link = menu.linkfaq()
+        self.assertEqual('add', link.icon)
+        # A question with a linked FAQ has an 'edit' icon.
+        self.person.addLanguage(getUtility(ILanguageSet)['en'])
+        target = self.question.target
+        target.addAnswerContact(self.person)
+        faq = self.factory.makeFAQ(target=target)
+        self.question.linkFAQ(self.person, faq, 'message')
+        link = menu.linkfaq()
+        self.assertEqual('edit', link.icon)
+
+
+def test_suite():
+    suite = unittest.TestSuite()
+    suite.addTest(unittest.TestLoader().loadTestsFromName(__name__))
+    return suite
+
+
+if __name__ == '__main__':
+    unittest.TextTestRunner().run(test_suite())

=== modified file 'lib/lp/answers/stories/question-add-in-other-languages.txt'
--- lib/lp/answers/stories/question-add-in-other-languages.txt	2009-11-01 04:47:40 +0000
+++ lib/lp/answers/stories/question-add-in-other-languages.txt	2009-11-11 22:17:17 +0000
@@ -91,8 +91,8 @@
     pt-BR
     >>> print soup.html['dir']
     ltr
-    >>> print soup.find('b', text='Language:').next.strip()
-    Portuguese (Brazil)
+    >>> print extract_text(find_tag_by_id(soup, 'question-lang'))
+    Language: Portuguese (Brazil) ...
 
 It's also possible that the user chose English in the first page but
 then changed his mind on the second page.

=== modified file 'lib/lp/answers/stories/question-add.txt'
--- lib/lp/answers/stories/question-add.txt	2009-11-01 04:47:40 +0000
+++ lib/lp/answers/stories/question-add.txt	2009-11-11 22:17:17 +0000
@@ -159,7 +159,7 @@
 
     >>> print extract_text(
     ...     find_tag_by_id(user_browser.contents, 'registration'))
-    Open... Question #..., asked...by...No Privileges Person...
+    Asked by No Privileges Person on ...
     >>> contents = find_main_content(user_browser.contents)
     >>> print extract_text(contents.find('div', 'report'))
     I use Ubuntu on AMD64 ...

=== modified file 'lib/lp/answers/stories/question-answer-contact.txt'
--- lib/lp/answers/stories/question-answer-contact.txt	2009-10-31 15:42:37 +0000
+++ lib/lp/answers/stories/question-answer-contact.txt	2009-11-11 22:17:17 +0000
@@ -196,7 +196,7 @@
     Question #10 : ...
 
     >>> print extract_text(find_tag_by_id(browser.contents, 'question-lang'))
-    Language: English
+    Language: English ...
 
     >>> portlet = find_tag_by_id(browser.contents, 'subscribers')
     >>> print extract_text(portlet)
@@ -213,7 +213,7 @@
     Question #12 : ...
 
     >>> print extract_text(find_tag_by_id(browser.contents, 'question-lang'))
-    Language: Spanish
+    Language: Spanish ...
 
     >>> portlet = find_tag_by_id(browser.contents, 'subscribers')
     >>> print extract_text(portlet).encode('ASCII', 'backslashreplace')

=== modified file 'lib/lp/answers/stories/question-confirm-url.txt'
--- lib/lp/answers/stories/question-confirm-url.txt	2009-09-28 09:11:17 +0000
+++ lib/lp/answers/stories/question-confirm-url.txt	2009-11-11 22:17:17 +0000
@@ -96,8 +96,8 @@
 This adds his comment to the question and mark it as 'Solved.'
 
     >>> print extract_text(
-    ...     find_tag_by_id(owner_browser.contents, 'registration'))
-    Solved ...
+    ...     find_tag_by_id(owner_browser.contents, 'question-status'))
+    Status: Solved ...
     >>> print find_tags_by_class(
     ...     owner_browser.contents, 'boardCommentBody')[-1].renderContents()
     <p>Thanks! This indeed solved the problem.</p>

=== modified file 'lib/lp/answers/stories/question-edit.txt'
--- lib/lp/answers/stories/question-edit.txt	2009-09-28 09:11:17 +0000
+++ lib/lp/answers/stories/question-edit.txt	2009-11-11 22:17:17 +0000
@@ -46,11 +46,11 @@
 
     >>> def print_question_status(browser):
     ...     print extract_text(
-    ...         find_tag_by_id(browser.contents, 'registration'))
+    ...         find_tag_by_id(browser.contents, 'question-status'))
 
     >>> user_browser.open('http://launchpad.dev/ubuntu/+question/3')
     >>> print_question_status(user_browser)
-    Invalid ...
+    Status: Invalid
 
     >>> user_browser.getLink('Edit question')
     <Link...>
@@ -93,8 +93,8 @@
     >>> browser.getControl('Save Changes').click()
 
     >>> soup = find_main_content(browser.contents)
-    >>> print soup.first('b', text='Whiteboard:').findNext('td').renderContents()
-    Some note
+    >>> print extract_text(find_tag_by_id(soup, 'question-whiteboard'))
+    Whiteboard: Some note
     >>> portlet_details = find_tag_by_id(browser.contents, 'portlet-details')
 
 Since the assignee is notified of changes to the question, his name also

=== modified file 'lib/lp/answers/stories/question-reject-and-change-status.txt'
--- lib/lp/answers/stories/question-reject-and-change-status.txt	2009-09-28 09:11:17 +0000
+++ lib/lp/answers/stories/question-reject-and-change-status.txt	2009-11-11 22:17:17 +0000
@@ -58,10 +58,10 @@
 
     >>> def print_question_status(browser):
     ...     print extract_text(
-    ...         find_tag_by_id(browser.contents, 'registration'))
+    ...         find_tag_by_id(browser.contents, 'question-status'))
 
     >>> print_question_status(admin_browser)
-    Invalid ...
+    Status: Invalid ...
 
 and the rejection message is added to the question board.
 
@@ -147,7 +147,7 @@
 its status is updated;
 
     >>> print_question_status(admin_browser)
-    Open ...
+    Status: Open ...
 
 and the explanation message is added to the question discussion:
 

=== modified file 'lib/lp/answers/stories/question-workflow.txt'
--- lib/lp/answers/stories/question-workflow.txt	2009-10-05 15:32:50 +0000
+++ lib/lp/answers/stories/question-workflow.txt	2009-11-11 22:17:17 +0000
@@ -15,7 +15,7 @@
     # added and the status of the question.
     >>> def find_request_status(contents):
     ...     print extract_text(
-    ...         find_tag_by_id(contents, 'registration'))
+    ...         find_tag_by_id(contents, 'question-status'))
 
     >>> def  find_last_comment(contents):
     ...     soup = find_main_content(contents)
@@ -70,7 +70,7 @@
 'Needs information':
 
     >>> find_request_status(support_browser.contents)
-    Needs information...
+    Status: Needs information
     >>> print_last_comment(support_browser.contents)
     Can you provide an example of an URL displaying the problem?
 
@@ -97,7 +97,7 @@
 status:
 
     >>> print find_request_status(support_browser.contents)
-    Needs information...
+    Status: Needs information ...
     >>> print_last_comment(support_browser.contents)
     I forgot to mention, in the meantime here is a workaround...
 
@@ -128,7 +128,7 @@
 discussion.
 
     >>> print find_request_status(owner_browser.contents)
-    Open...
+    Status: Open ...
     >>> print_last_comment(owner_browser.contents)
     The following SVG doesn't display properly:
     http://www.w3.org/2001/08/rdfweb/rdfweb-chaals-and-dan.svg
@@ -151,7 +151,7 @@
 answer to the end of the discussion:
 
     >>> print find_request_status(support_browser.contents)
-    Answered...
+    Status: Answered ...
     >>> print_last_comment(support_browser.contents)
     New version of the firefox package are available with SVG support
     enabled. You can use apt-get or adept to upgrade.
@@ -189,7 +189,7 @@
 'No Privileges Person' as the solver.
 
     >>> print find_request_status(owner_browser.contents)
-    Solved Question #2, solved on ... by No Privileges Person...
+    Status: Solved ...
 
 Since no message can be provided when that button is clicked. A default
 confirmation message was appended to the question discussion:
@@ -232,7 +232,7 @@
 status:
 
     >>> print find_request_status(owner_browser.contents)
-    Solved...
+    Status: Solved ...
     >>> print_last_comment(owner_browser.contents)
     The example now displays correctly. Thanks.
 
@@ -255,7 +255,7 @@
 its status back to 'Open'.
 
     >>> print find_request_status(owner_browser.contents)
-    Open...
+    Status: Open ...
     >>> print_last_comment(owner_browser.contents)
     Actually, there are still SVGs that do not display correctly.
     For example, the following
@@ -299,7 +299,7 @@
 message as the "Best answer".
 
     >>> find_request_status(owner_browser.contents)
-    Solved Question #2, solved on ... by Sample Person...
+    Status: Solved ...
     >>> soup = find_tag_by_id(owner_browser.contents, 'portlet-details')
     >>> soup = find_main_content(owner_browser.contents)
     >>> bestAnswer = soup.first('img', {'title': 'Marked as best answer'})
@@ -320,7 +320,7 @@
 
     >>> owner_browser.getControl('This Solved My Problem').click()
     >>> find_request_status(owner_browser.contents)
-    Solved Question #2, solved on ... by No Privileges Person...
+    Status: Solved ...
 
 The answer's message is also highlighted as the best answer.
 
@@ -389,7 +389,7 @@
     >>> carlos_browser = setupBrowser(auth='Basic carlos@canonical.com:test')
     >>> carlos_browser.open('http://launchpad.dev/firefox/+question/12')
     >>> print find_request_status(carlos_browser.contents)
-    Open...
+    Status: Open ...
 
     >>> answer_button_paragraph = find_tag_by_id(
     ...     carlos_browser.contents, 'answer-button-hint')
@@ -400,7 +400,7 @@
     ...     "There is a bug in that version. SMP is fine after upgrading.")
     >>> carlos_browser.getControl("Problem Solved").click()
     >>> print find_request_status(carlos_browser.contents)
-    Solved...
+    Status: Solved ...
 
     >>> content = find_main_content(carlos_browser.contents)
     >>> messages = content.findAll('div', 'informational message')

=== modified file 'lib/lp/answers/stories/this-is-a-faq.txt'
--- lib/lp/answers/stories/this-is-a-faq.txt	2009-10-31 15:42:37 +0000
+++ lib/lp/answers/stories/this-is-a-faq.txt	2009-11-11 22:17:17 +0000
@@ -104,16 +104,16 @@
 
     >>> def print_question_status(browser):
     ...     print extract_text(
-    ...         find_tag_by_id(browser.contents, 'registration'))
+    ...         find_tag_by_id(browser.contents, 'question-status'))
 
     >>> print_question_status(user_browser)
-    Answered ...
+    Status: Answered
 
 A link to the FAQ appears under the question's description:
 
     >>> print extract_text(
     ...     find_tag_by_id(user_browser.contents, 'related-faq'))
-    Related FAQ: How do I install plugins (Shockwave, QuickTime, etc.)?
+    Related FAQ: How do I install plugins (Shockwave, QuickTime, etc.)? ...
     >>> print user_browser.getLink('How do I install plugins').url
     http://answers.launchpad.dev/firefox/+faq/10
 
@@ -176,8 +176,9 @@
 
 The link was also removed from the details portlet:
 
-    >>> print find_tag_by_id(user_browser.contents, 'related-faq')
-    None
+    >>> print extract_text(
+    ...     find_tag_by_id(user_browser.contents, 'related-faq'))
+    Related FAQ: None ...
 
 
 == Creating a new FAQ ==
@@ -267,7 +268,7 @@
 
     >>> print extract_text(
     ...     find_tag_by_id(owner_browser.contents, 'related-faq'))
-    Related FAQ: Displaying SVG in Firefox
+    Related FAQ: Displaying SVG in Firefox ...
 
 
 == Viewing a FAQ ==
@@ -350,7 +351,7 @@
     >>> details_portlet = find_portlet(
     ...     user_browser.contents, 'mozilla-firefox in ubuntu question #9')
     >>> print_question_status(user_browser)
-    Solved...
+    Status: Solved
     >>> user_browser.getLink('Link to a FAQ').click()
 
     >>> print user_browser.title
@@ -368,7 +369,7 @@
     >>> print user_browser.title
     Question #9 : ...
     >>> print_question_status(user_browser)
-    Solved...
+    Status: Solved
 
     >>> print extract_text(
     ...     find_tag_by_id(user_browser.contents, 'related-faq'))

=== modified file 'lib/lp/answers/templates/question-index.pt'
--- lib/lp/answers/templates/question-index.pt	2009-09-28 09:11:17 +0000
+++ lib/lp/answers/templates/question-index.pt	2009-11-11 22:17:17 +0000
@@ -19,72 +19,84 @@
   </head>
   <body>
     <metal:registering fill-slot="registering">
-        <span class="questionstatusOPEN"
-          tal:attributes="class string:questionstatus${context/status/name}"
-          tal:content="context/status/title">Open</span>
-        Question #<span tal:replace="context/id">4</span>,
-
-        <tal:answerer condition="context/answerer">
-          solved
-          <span
-            tal:attributes="title context/datecreated/fmt:datetime"
-            tal:content="context/datecreated/fmt:displaydate">2005-10-05</span>
-          by
-          <a tal:replace="structure context/answerer/fmt:link">
-            Foo Bar
-          </a>,
-        </tal:answerer>
-
-        asked
-        <span
+        Asked by
+        <a tal:replace="structure context/owner/fmt:link" />
+        on <span
           tal:attributes="title context/datecreated/fmt:datetime"
           tal:content="context/datecreated/fmt:displaydate">2005-10-05</span>
-        by
-        <a
-          tal:attributes="href context/owner/fmt:url"
-          tal:content="context/owner/displayname">Foo Bar</a>
+
     </metal:registering>
 
 
     <metal:portlets fill-slot="side">
       <div tal:replace="structure context/@@+global-actions" />
-      <div tal:condition="context/reopenings"
-           tal:replace="structure context/@@+portlet-reopenings" />
       <div tal:replace="structure context/@@+portlet-subscribers" />
-      <div tal:replace="structure context/@@+portlet-bugs" />
     </metal:portlets>
 
     <div metal:fill-slot="main">
-
-      <div id="question-lang" style="margin-bottom: 1em">
-        <b>Language:</b>
-        <span tal:replace="context/language/englishname">English</span><br />
-      </div>
-
       <tal:description
         define="global description context/description/fmt:obfuscate-email/fmt:text-to-html" />
 
-      <p id="original-bug"
-        tal:define="bug view/original_bug"
-        tal:condition="bug">
-        This question was originally filed as
-        <a href="#"
-          tal:attributes="href bug/fmt:url">bug
-          #<tal:num replace="bug/id" /></a>.
-      </p>
-
-      <div
-        class="report"
-        tal:content="structure description"
-        />
-
-      <div id="related-faq" tal:condition="context/faq">
-        <b>Related FAQ:</b>
-        <a href="#"
-           tal:attributes="href context/faq/fmt:url"
-           tal:content="context/faq/title">FAQ Title</a>
+      <div class="report"
+        tal:content="structure description"/>
+
+      <div class="yui-g">
+        <div class="yui-u first">
+           <tal:distro-information content="structure context/@@+portlet-details" />
+        </div>
+
+        <div class="yui-u">
+          <div class="portlet">
+            <h2>Related bugs</h2>
+
+            <ul
+              tal:define="bugs context/bugs"
+              tal:condition="bugs">
+              <li tal:repeat="bug bugs">
+                <a tal:replace="structure bug/fmt:link" />
+              </li>
+            </ul>
+
+            <p id="original-bug"
+              tal:define="bug view/original_bug"
+              tal:condition="bug">
+              This question was originally filed as
+              <a href="#"
+                tal:attributes="href bug/fmt:url">bug
+                #<tal:num replace="bug/id" /></a>.
+            </p>
+
+            <ul class="horizontal">
+              <li 
+                tal:define="link context/menu:answers/linkbug"
+                tal:content="structure link/fmt:link" />
+              <li tal:condition="context/bugs"
+                tal:define="link context/menu:answers/unlinkbug"
+                tal:content="structure link/fmt:link" />
+            </ul>
+
+            <div id="related-faq" style="margin-top: 1em;">
+              <h2>Related FAQ:</h2>
+              
+              <p>
+                <a class="sprite question"
+                  tal:condition="context/faq"
+                  tal:attributes="href context/faq/fmt:url"
+                  tal:content="context/faq/title">FAQ Title</a>
+                <tal:none tal:condition="not: context/faq">
+                  None
+                </tal:none>
+                <a tal:replace="structure context/menu:answers/linkfaq/fmt:icon" />
+               </p>
+            </div>
+
+            <div tal:condition="context/reopenings"
+                 tal:replace="structure context/@@+portlet-reopenings" />
+          </div>
+        </div>
       </div>
 
+
       <tal:message repeat="message context/messages">
         <div tal:replace="structure message/@@+display" />
       </tal:message>
@@ -109,8 +121,6 @@
                 tal:content="structure link/render" />
             <li tal:define="link context/menu:answers/linkbug"
                 tal:content="structure link/render" />
-            <li tal:define="link context/menu:answers/unlinkbug"
-                tal:content="structure link/render" />
             <li tal:define="link context/menu:answers/makebug"
                 tal:content="structure link/render" />
             <li tal:define="link context/menu:answers/linkfaq"
@@ -121,18 +131,6 @@
           </ul>
         </div>
 
-        <table class="listing" xml:lang="en" lang="en" dir="ltr"
-          tal:condition="context/whiteboard">
-          <tbody>
-            <tr>
-              <td><b>Whiteboard:</b></td>
-              <td tal:content="context/whiteboard">
-                whiteboard contents
-              </td>
-            </tr>
-          </tbody>
-        </table>
-
         <div tal:condition="view/hasActions">
           <div metal:use-macro="context/@@launchpad_form/form">
             <metal:no-heading fill-slot="heading" />

=== modified file 'lib/lp/answers/templates/question-portlet-details.pt'
--- lib/lp/answers/templates/question-portlet-details.pt	2009-07-17 17:59:07 +0000
+++ lib/lp/answers/templates/question-portlet-details.pt	2009-11-11 22:17:17 +0000
@@ -4,78 +4,96 @@
   xmlns:i18n="http://xml.zope.org/namespaces/i18n"
   omit-tag="">
 
-<div class="portlet" id="portlet-details">
-
-  <h2><span tal:replace="context/target/displayname">Ubuntu</span> question
-      #<span tal:replace="context/id">234</span></h2>
-
-  <div class="portletBody portletContent">
-
-    <b>Question from:</b><br />
-    <a tal:replace="structure context/owner/fmt:link">Foo Bar</a><br />
-
-    <b>Language:</b>
-    <span tal:replace="context/language/englishname">English</span><br />
-
-    <b>Status:</b>
-    <span tal:replace="context/status/title">Open</span><br />
-
-    <b>For:</b>
-    <span tal:condition="context/product"
-          tal:replace="context/product/name">Firefox</span>
-    <span tal:condition="context/distribution"
-          tal:replace="context/distribution/name">ubuntu</span>
-    <span tal:condition="context/sourcepackagename"
-          tal:replace="context/sourcepackagename/name">moz-ff</span>
-    <br />
-
-    <tal:block condition="context/datedue">
-      <b>Due:</b>
-      <span
-        tal:attributes="title context/datedue/fmt:datetime"
-        tal:content="context/datedue/fmt:approximatedate" /><br />
-    </tal:block>
-
-    <b>Created:</b>
-    <span
-      tal:attributes="title context/datecreated/fmt:datetime"
-      tal:content="context/datecreated/fmt:approximatedate" /><br />
-
-    <b>Assignee:</b><br />
-    <tal:block condition="context/assignee">
-      <a tal:replace="structure context/assignee/fmt:link">Foo Bar</a>
-    </tal:block>
-    <tal:block condition="not: context/assignee">
-      <i>No assignee</i>
-    </tal:block>
-    <br />
-
-    <tal:block condition="context/answerer">
-      <b>Solved by:</b><br />
-      <a tal:replace="structure context/answerer/fmt:link">Foo Bar</a>
-      <br />
-    </tal:block>
-
-    <b>Last query:</b>
-    <span
-      tal:attributes="title context/datelastquery/fmt:datetime"
-      tal:content="context/datelastquery/fmt:approximatedate" /><br />
-
-    <tal:block condition="context/datelastresponse">
-      <b>Last reply:</b>
-      <span
-        tal:attributes="title context/datelastresponse/fmt:datetime"
-        tal:content="context/datelastresponse/fmt:approximatedate" /><br />
-    </tal:block>
-
-    <tal:block condition="context/date_solved">
-      <b>Solved:</b>
-      <span
-        tal:attributes="title context/date_solved/fmt:datetime"
-        tal:content="context/date_solved/fmt:approximatedate" /><br />
-    </tal:block>
-
+<div class="portlet" id="portlet-details" xml:lang="en" lang="en" dir="ltr">
+
+  <h2>Question information</h2>
+
+  <div class="two-column-list">
+    <dl id="question-lang">
+      <dt>Language:</dt>
+      <dd>
+        <tal:language content="context/language/englishname" />
+        <a tal:replace="structure context/menu:answers/edit/fmt:icon" />
+      </dd>
+    </dl>
+    
+    <dl id="question-status">
+      <dt>Status:</dt>
+      <dd>
+        <span class="questionstatusOPEN"
+          tal:attributes="class string:questionstatus${context/status/name}"
+          tal:content="context/status/title">Open</span>
+        <a tal:replace="structure context/menu:answers/changestatus/fmt:icon" />
+      </dd>
+    </dl>
+
+    <dl>
+      <dt>For:</dt>
+      <dd>
+        <a tal:condition="context/product"
+          tal:replace="structure context/product/fmt:link">Firefox</a>
+        <a tal:condition="context/distribution"
+          tal:replace="structure context/distribution/fmt:link">ubuntu</a>
+        <a tal:condition="context/sourcepackagename"
+          tal:attributes="href
+          string:${context/distribution/fmt:url}/+source/${context/sourcepackagename/name}">
+          mozilla-firefox</a>
+        <a tal:replace="structure context/menu:answers/edit/fmt:icon" />
+      </dd>
+    </dl>
+
+    <dl>
+      <dt>Assignee:</dt>
+      <dd>
+        <tal:block condition="context/assignee">
+          <a tal:replace="structure context/assignee/fmt:link">Foo Bar</a>
+        </tal:block>
+        <tal:block condition="not: context/assignee">
+          No assignee
+        </tal:block>
+        <a tal:replace="structure context/menu:answers/edit/fmt:icon" />
+      </dd>
+    </dl>
+
+    <dl tal:condition="context/answerer">
+      <dt>Solved by:</dt>
+      <dd>
+        <a tal:replace="structure context/answerer/fmt:link">Foo Bar</a>
+      </dd>
+    </dl>
+
+    <dl tal:condition="context/answerer">
+      <dt>Solved:</dt>
+      <dd>
+        <span
+          tal:attributes="title context/date_solved/fmt:datetime"
+          tal:content="context/date_solved/fmt:approximatedate" />
+      </dd>
+    </dl>
+
+    <dl style="clear: both;">
+      <dt>Last query:</dt>
+      <dd>
+        <span
+          tal:attributes="title context/datelastquery/fmt:datetime"
+          tal:content="context/datelastquery/fmt:approximatedate" />
+      </dd>
+    </dl>
+
+    <dl>
+      <dt>Last reply:</dt>
+      <dd>
+        <span
+          tal:attributes="title context/datelastresponse/fmt:datetime"
+          tal:content="context/datelastresponse/fmt:approximatedate" />
+      </dd>
+    </dl>
   </div>
 
+  <dl id="question-whiteboard"
+    tal:condition="context/whiteboard">
+    <dt>Whiteboard:</dt>
+    <dd tal:content="context/whiteboard">contents</dd>
+  </dl>
 </div>
 </tal:root>

=== modified file 'lib/lp/testing/menu.py'
--- lib/lp/testing/menu.py	2009-09-10 20:35:24 +0000
+++ lib/lp/testing/menu.py	2009-11-11 22:17:17 +0000
@@ -26,4 +26,4 @@
         except:
             is_sane_menu = False
             print 'Bad link %s: %s' % (link.name, url)
-    print is_sane_menu
+    return is_sane_menu

